@@ -6,7 +6,7 @@
  *   copyright            : (C) 2001 The phpBB Group
  *   email                : support@phpbb.com
  *
- *   $Id: privmsg.php,v 1.96.2.44 2005/12/22 12:54:56 acydburn Exp $
+ *   $Id: privmsg.php,v 1.96.2.35 2004/03/28 16:38:51 acydburn Exp $
  *
  *
  ***************************************************************************/
@@ -35,8 +35,8 @@ if ( !empty($board_config['privmsg_disable']) )
 	message_die(GENERAL_MESSAGE, 'PM_disabled');
 }
 
-$html_entities_match = array('#&(?!(\#[0-9]+;))#', '#<#', '#>#', '#"#');
-$html_entities_replace = array('&amp;', '&lt;', '&gt;', '&quot;');
+$html_entities_match = array('#&(?!(\#[0-9]+;))#', '#<#', '#>#');
+$html_entities_replace = array('&amp;', '&lt;', '&gt;');
 
 //
 // Parameters
@@ -295,7 +295,7 @@ else if ( $mode == 'read' )
 
 		if ( $sent_info = $db->sql_fetchrow($result) )
 		{
-			if ($board_config['max_sentbox_privmsgs'] && $sent_info['sent_items'] >= $board_config['max_sentbox_privmsgs'])
+			if ( $sent_info['sent_items'] >= $board_config['max_sentbox_privmsgs'] )
 			{
 				$sql = "SELECT privmsgs_id FROM " . PRIVMSGS_TABLE . " 
 					WHERE privmsgs_type = " . PRIVMSGS_SENT_MAIL . " 
@@ -493,7 +493,7 @@ else if ( $mode == 'read' )
 	$profile_img = '<a href="' . $temp_url . '"><img src="' . $images['icon_profile'] . '" alt="' . $lang['Read_profile'] . '" title="' . $lang['Read_profile'] . '" border="0" /></a>';
 	$profile = '<a href="' . $temp_url . '">' . $lang['Read_profile'] . '</a>';
 
-	$temp_url = append_sid("privmsg.$phpEx?mode=post&amp;" . POST_USERS_URL . "=$user_id_from");
+	$temp_url = append_sid("privmsg.$phpEx?mode=post&amp;" . POST_USERS_URL . "=$poster_id");
 	$pm_img = '<a href="' . $temp_url . '"><img src="' . $images['icon_pm'] . '" alt="' . $lang['Send_private_message'] . '" title="' . $lang['Send_private_message'] . '" border="0" /></a>';
 	$pm = '<a href="' . $temp_url . '">' . $lang['Send_private_message'] . '</a>';
 
@@ -537,8 +537,8 @@ else if ( $mode == 'read' )
 	$yim = ( $privmsg['user_yim'] ) ? '<a href="http://edit.yahoo.com/config/send_webmesg?.target=' . $privmsg['user_yim'] . '&amp;.src=pg">' . $lang['YIM'] . '</a>' : '';
 
 	$temp_url = append_sid("search.$phpEx?search_author=" . urlencode($username_from) . "&amp;showresults=posts");
-	$search_img = '<a href="' . $temp_url . '"><img src="' . $images['icon_search'] . '" alt="' . sprintf($lang['Search_user_posts'], $username_from) . '" title="' . sprintf($lang['Search_user_posts'], $username_from) . '" border="0" /></a>';
-	$search = '<a href="' . $temp_url . '">' . sprintf($lang['Search_user_posts'], $username_from) . '</a>';
+	$search_img = '<a href="' . $temp_url . '"><img src="' . $images['icon_search'] . '" alt="' . $lang['Search_user_posts'] . '" title="' . $lang['Search_user_posts'] . '" border="0" /></a>';
+	$search = '<a href="' . $temp_url . '">' . $lang['Search_user_posts'] . '</a>';
 
 	//
 	// Processing of post
@@ -563,9 +563,9 @@ else if ( $mode == 'read' )
 	// If the board has HTML off but the post has HTML
 	// on then we process it, else leave it alone
 	//
-	if ( !$board_config['allow_html'] || !$userdata['user_allowhtml'])
+	if ( !$board_config['allow_html'] )
 	{
-		if ( $user_sig != '')
+		if ( $user_sig != '' && $privmsg['privmsgs_enable_sig'] && $userdata['user_allowhtml'] )
 		{
 			$user_sig = preg_replace('#(<)([\/]?.*?)(>)#is', "&lt;\\2&gt;", $user_sig);
 		}
@@ -698,57 +698,47 @@ else if ( ( $delete && $mark_list ) || $delete_all )
 	}
 	else if ( $confirm )
 	{
-		$delete_sql_id = '';
-
-		if (!$delete_all)
+		if ( $delete_all )
 		{
-			for ($i = 0; $i < count($mark_list); $i++)
+			switch($folder)
 			{
-				$delete_sql_id .= (($delete_sql_id != '') ? ', ' : '') . intval($mark_list[$i]);
+				case 'inbox':
+					$delete_type = "privmsgs_to_userid = " . $userdata['user_id'] . " AND (
+					privmsgs_type = " . PRIVMSGS_READ_MAIL . " OR privmsgs_type = " . PRIVMSGS_NEW_MAIL . " OR privmsgs_type = " . PRIVMSGS_UNREAD_MAIL . " )";
+					break;
+
+				case 'outbox':
+					$delete_type = "privmsgs_from_userid = " . $userdata['user_id'] . " AND ( privmsgs_type = " . PRIVMSGS_NEW_MAIL . " OR privmsgs_type = " . PRIVMSGS_UNREAD_MAIL . " )";
+					break;
+
+				case 'sentbox':
+					$delete_type = "privmsgs_from_userid = " . $userdata['user_id'] . " AND privmsgs_type = " . PRIVMSGS_SENT_MAIL;
+					break;
+
+				case 'savebox':
+					$delete_type = "( ( privmsgs_from_userid = " . $userdata['user_id'] . " 
+						AND privmsgs_type = " . PRIVMSGS_SAVED_OUT_MAIL . " ) 
+					OR ( privmsgs_to_userid = " . $userdata['user_id'] . " 
+						AND privmsgs_type = " . PRIVMSGS_SAVED_IN_MAIL . " ) )";
+					break;
 			}
-			$delete_sql_id = "AND privmsgs_id IN ($delete_sql_id)";
+
+			$sql = "SELECT privmsgs_id
+				FROM " . PRIVMSGS_TABLE . "
+				WHERE $delete_type";
+			if ( !($result = $db->sql_query($sql)) )
+			{
+				message_die(GENERAL_ERROR, 'Could not obtain id list to delete all messages', '', __LINE__, __FILE__, $sql);
+			}
+
+			while ( $row = $db->sql_fetchrow($result) )
+			{
+				$mark_list[] = $row['privmsgs_id'];
+			}
+
+			unset($delete_type);
 		}
 
-		switch($folder)
-		{
-			case 'inbox':
-				$delete_type = "privmsgs_to_userid = " . $userdata['user_id'] . " AND (
-				privmsgs_type = " . PRIVMSGS_READ_MAIL . " OR privmsgs_type = " . PRIVMSGS_NEW_MAIL . " OR privmsgs_type = " . PRIVMSGS_UNREAD_MAIL . " )";
-				break;
-
-			case 'outbox':
-				$delete_type = "privmsgs_from_userid = " . $userdata['user_id'] . " AND ( privmsgs_type = " . PRIVMSGS_NEW_MAIL . " OR privmsgs_type = " . PRIVMSGS_UNREAD_MAIL . " )";
-				break;
-
-			case 'sentbox':
-				$delete_type = "privmsgs_from_userid = " . $userdata['user_id'] . " AND privmsgs_type = " . PRIVMSGS_SENT_MAIL;
-				break;
-
-			case 'savebox':
-				$delete_type = "( ( privmsgs_from_userid = " . $userdata['user_id'] . " 
-					AND privmsgs_type = " . PRIVMSGS_SAVED_OUT_MAIL . " ) 
-				OR ( privmsgs_to_userid = " . $userdata['user_id'] . " 
-					AND privmsgs_type = " . PRIVMSGS_SAVED_IN_MAIL . " ) )";
-				break;
-		}
-
-		$sql = "SELECT privmsgs_id
-			FROM " . PRIVMSGS_TABLE . "
-			WHERE $delete_type $delete_sql_id";
-
-		if ( !($result = $db->sql_query($sql)) )
-		{
-			message_die(GENERAL_ERROR, 'Could not obtain id list to delete messages', '', __LINE__, __FILE__, $sql);
-		}
-
-		$mark_list = array();
-		while ( $row = $db->sql_fetchrow($result) )
-		{
-			$mark_list[] = $row['privmsgs_id'];
-		}
-
-		unset($delete_type);
-
 		if ( count($mark_list) )
 		{
 			$delete_sql_id = '';
@@ -911,7 +901,7 @@ else if ( $save && $mark_list && $folder != 'savebox' && $folder != 'outbox' )
 
 		if ( $saved_info = $db->sql_fetchrow($result) )
 		{
-			if ($board_config['max_savebox_privmsgs'] && $saved_info['savebox_items'] >= $board_config['max_savebox_privmsgs'] )
+			if ( $saved_info['savebox_items'] >= $board_config['max_savebox_privmsgs'] )
 			{
 				$sql = "SELECT privmsgs_id FROM " . PRIVMSGS_TABLE . " 
 					WHERE ( ( privmsgs_to_userid = " . $userdata['user_id'] . " 
@@ -1052,7 +1042,7 @@ else if ( $save && $mark_list && $folder != 'savebox' && $folder != 'outbox' )
 				$saved_sql .= " SET privmsgs_type = " . PRIVMSGS_SAVED_OUT_MAIL . " 
 					WHERE privmsgs_from_userid = " . $userdata['user_id'] . " 
 						AND ( privmsgs_type = " . PRIVMSGS_NEW_MAIL . " 
-							OR privmsgs_type = " . PRIVMSGS_UNREAD_MAIL . " ) ";
+							OR privmsgs_type = " . PRIVMSGS_UNERAD_MAIL . " ) ";
 				break;
 
 			case 'sentbox':
@@ -1138,32 +1128,11 @@ else if ( $submit || $refresh || $mode != '' )
 		//
 	}
 
-	if ($submit && $mode == 'edit')
-	{
-		$sql = 'SELECT privmsgs_from_userid
-			FROM ' . PRIVMSGS_TABLE . '
-			WHERE privmsgs_id = ' . (int) $privmsg_id . '
-				AND privmsgs_from_userid = ' . $userdata['user_id'];
-
-		if (!($result = $db->sql_query($sql)))
-		{
-			message_die(GENERAL_ERROR, "Could not obtain message details", "", __LINE__, __FILE__, $sql);
-		}
-
-		if (!($row = $db->sql_fetchrow($result)))
-		{
-			message_die(GENERAL_MESSAGE, $lang['No_such_post']);
-		}
-		$db->sql_freeresult($result);
-
-		unset($row);
-	}
-
 	if ( $submit )
 	{
 		if ( !empty($HTTP_POST_VARS['username']) )
 		{
-			$to_username = phpbb_clean_username($HTTP_POST_VARS['username']);
+			$to_username = $HTTP_POST_VARS['username'];
 
 			$sql = "SELECT user_id, user_notify_pm, user_email, user_lang, user_active 
 				FROM " . USERS_TABLE . "
@@ -1175,11 +1144,7 @@ else if ( $submit || $refresh || $mode != '' )
 				$error_msg = $lang['No_such_user'];
 			}
 
-			if (!($to_userdata = $db->sql_fetchrow($result)))
-			{
-				$error = TRUE;
-				$error_msg = $lang['No_such_user'];
-			}
+			$to_userdata = $db->sql_fetchrow($result);
 		}
 		else
 		{
@@ -1247,7 +1212,7 @@ else if ( $submit || $refresh || $mode != '' )
 
 			if ( $inbox_info = $db->sql_fetchrow($result) )
 			{
-				if ($board_config['max_inbox_privmsgs'] && $inbox_info['inbox_items'] >= $board_config['max_inbox_privmsgs'])
+				if ( $inbox_info['inbox_items'] >= $board_config['max_inbox_privmsgs'] )
 				{
 					$sql = "SELECT privmsgs_id FROM " . PRIVMSGS_TABLE . " 
 						WHERE ( privmsgs_type = " . PRIVMSGS_NEW_MAIL . " 
@@ -1344,7 +1309,7 @@ else if ( $submit || $refresh || $mode != '' )
 				$emailer->set_subject($lang['Notification_subject']);
 					
 				$emailer->assign_vars(array(
-					'USERNAME' => stripslashes($to_username), 
+					'USERNAME' => $to_username, 
 					'SITENAME' => $board_config['sitename'],
 					'EMAIL_SIG' => (!empty($board_config['board_email_sig'])) ? str_replace('<br />', "\n", "-- \n" . $board_config['board_email_sig']) : '', 
 
@@ -1372,8 +1337,7 @@ else if ( $submit || $refresh || $mode != '' )
 		// passed to the script, process it a little, do some checks
 		// where neccessary, etc.
 		//
-		$to_username = (isset($HTTP_POST_VARS['username']) ) ? trim(htmlspecialchars(stripslashes($HTTP_POST_VARS['username']))) : '';
-
+		$to_username = ( isset($HTTP_POST_VARS['username']) ) ? trim(strip_tags(stripslashes($HTTP_POST_VARS['username']))) : '';
 		$privmsg_subject = ( isset($HTTP_POST_VARS['subject']) ) ? trim(strip_tags(stripslashes($HTTP_POST_VARS['subject']))) : '';
 		$privmsg_message = ( isset($HTTP_POST_VARS['message']) ) ? trim($HTTP_POST_VARS['message']) : '';
 		$privmsg_message = preg_replace('#<textarea>#si', '&lt;textarea&gt;', $privmsg_message);
@@ -1449,7 +1413,8 @@ else if ( $submit || $refresh || $mode != '' )
 				$to_username = $row['username'];
 			}
 		}
-		else if ( $mode == 'edit' )
+
+		if ( $mode == 'edit' )
 		{
 			$sql = "SELECT pm.*, pmt.privmsgs_bbcode_uid, pmt.privmsgs_text, u.username, u.user_id, u.user_sig 
 				FROM " . PRIVMSGS_TABLE . " pm, " . PRIVMSGS_TEXT_TABLE . " pmt, " . USERS_TABLE . " u
@@ -1528,10 +1493,6 @@ else if ( $submit || $refresh || $mode != '' )
 				$mode = 'reply';
 			}
 		}
-		else
-		{
-			$privmsg_subject = $privmsg_message = $to_username = '';
-		}
 	}
 
 	//
@@ -1566,9 +1527,9 @@ else if ( $submit || $refresh || $mode != '' )
 		//
 		// Finalise processing as per viewtopic
 		//
-		if ( !$html_on || !$board_config['allow_html'] || !$userdata['user_allowhtml'] )
+		if ( !$html_on )
 		{
-			if ( $user_sig != '' )
+			if ( $user_sig != '' || !$userdata['user_allowhtml'] )
 			{
 				$user_sig = preg_replace('#(<)([\/]?.*?)(>)#is', "&lt;\\2&gt;", $user_sig);
 			}
@@ -1746,7 +1707,7 @@ else if ( $submit || $refresh || $mode != '' )
 
 	$template->assign_vars(array(
 		'SUBJECT' => $privmsg_subject, 
-		'USERNAME' => $to_username,
+		'USERNAME' => preg_replace($html_entities_match, $html_entities_replace, $to_username),
 		'MESSAGE' => $privmsg_message,
 		'HTML_STATUS' => $html_status, 
 		'SMILIES_STATUS' => $smilies_status, 
@@ -1823,6 +1784,7 @@ else if ( $submit || $refresh || $mode != '' )
 		'S_BBCODE_CHECKED' => ( !$bbcode_on ) ? ' checked="checked"' : '', 
 		'S_SMILIES_CHECKED' => ( !$smilies_on ) ? ' checked="checked"' : '', 
 		'S_SIGNATURE_CHECKED' => ( $attach_sig ) ? ' checked="checked"' : '', 
+		'S_NAMES_SELECT' => $user_names_select,
 		'S_HIDDEN_FORM_FIELDS' => $s_hidden_fields,
 		'S_POST_ACTION' => append_sid("privmsg.$phpEx"),
 			
@@ -1890,7 +1852,7 @@ obtain_word_list($orig_word, $replacement_word);
 //
 // New message
 //
-$post_new_mesg_url = '<a href="' . append_sid("privmsg.$phpEx?mode=post") . '"><img src="' . $images['post_new'] . '" alt="' . $lang['Send_a_new_message'] . '" border="0" /></a>';
+$post_new_mesg_url = '<a href="' . append_sid("privmsg.$phpEx?mode=post") . '"><img src="' . $images['post_new'] . '" alt="' . $lang['Post_new_message'] . '" border="0" /></a>';
 
 //
 // General SQL to obtain messages
@@ -1970,8 +1932,8 @@ if ( $submit_msgdays && ( !empty($HTTP_POST_VARS['msgdays']) || !empty($HTTP_GET
 }
 else
 {
-	$limit_msg_time = $limit_msg_time_total = '';
-	$msg_days = 0;
+	$limit_msg_time = '';
+	$post_days = 0;
 }
 
 $sql .= $limit_msg_time . " ORDER BY pm.privmsgs_date DESC LIMIT $start, " . $board_config['topics_per_page'];
@@ -2057,10 +2019,6 @@ if ( $folder != 'outbox' )
 			break;
 	}
 }
-else
-{
-	$inbox_limit_img_length = $inbox_limit_pct = $l_box_size_status = '';
-}
 
 //
 // Dump vars to template
@@ -2105,7 +2063,7 @@ $template->assign_vars(array(
 	'S_POST_NEW_MSG' => $post_new_mesg_url,
 	'S_SELECT_MSG_DAYS' => $select_msg_days,
 
-	'U_POST_NEW_TOPIC' => append_sid("privmsg.$phpEx?mode=post"))
+	'U_POST_NEW_TOPIC' => $post_new_topic_url)
 );
 
 //
@@ -2194,4 +2152,4 @@ $template->pparse('body');
 
 include($phpbb_root_path . 'includes/page_tail.'.$phpEx);
 
-?>
\ No newline at end of file
+?>
